variable "automated_snapshot_start_hour" {
  type = number
}

variable "aws_arn_prefix" {
  description = "Arn Prefix for AWS resources. Gov: arn:aws-us-gov, Com: arn:aws"
  type        = string
}

variable "dedicated_master_enabled" {
  type = bool
}

variable "dedicated_master_type" {
  type = string
}

variable "dedicated_master_count" {
  type = number
}

variable "domain_name" {
  type = string
}

variable "ebs_options" {
  description = "Nested configuration block values if ebs_enabled instance is desired."
  type = object({
    iops        = number
    volume_size = number
    volume_type = string
  })
  default = null
}

variable "engine_version" {
  type = string

  validation {
    condition     = can(regex("^(OpenSearch_)([0-9])\\.([0-9]{1,2})$", var.engine_version))
    error_message = "Does not match ^(OpenSearch_)([0-9])\\.([0-9]{1,2})$ ."
  }
}

variable "instance_count" {
  type = number
}

variable "instance_type" {
  type = string
}

## one for each: INDEX_SLOW_LOGS, SEARCH_SLOW_LOGS, ES_APPLICATION_LOGS, AUDIT_LOGS

variable "log_retention_index_slow_logs" {
  description = <<-EOT
  Specifies the number of days you want to retain INDEX_SLOW_LOGS log events.
  Possible values are: 1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1827, 3653, and 0.
  If you select 0, the events in the log group are always retained and never expire.
  EOT
  type        = number
  default     = null

  validation {
    condition = (
      var.log_retention_index_slow_logs == null ||
      contains([1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1827, 3653, 0], coalesce(var.log_retention_index_slow_logs, 2))
    )

    error_message = "Valid log retention values: 1,3,5,7,14,30,60,90,120,150,180,365,400,545,731,1827,3653,0."
  }
}

variable "log_retention_search_slow_logs" {
  description = <<-EOT
  Specifies the number of days you want to retain SEARCH_SLOW_LOGS log events.
  Possible values are: 1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1827, 3653, and 0.
  If you select 0, the events in the log group are always retained and never expire.
  EOT
  type        = number
  default     = null

  validation {
    condition = (
      var.log_retention_search_slow_logs == null ||
      contains([1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1827, 3653, 0], coalesce(var.log_retention_search_slow_logs, 2))
    )

    error_message = "Valid log retention values: 1,3,5,7,14,30,60,90,120,150,180,365,400,545,731,1827,3653,0."
  }
}

variable "log_retention_es_application_logs" {
  description = <<-EOT
  Specifies the number of days you want to retain ES_APPLICATION_LOGS log events.
  Possible values are: 1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1827, 3653, and 0.
  If you select 0, the events in the log group are always retained and never expire.
  EOT
  type        = number
  default     = null

  validation {
    condition = (
      var.log_retention_es_application_logs == null ||
      contains([1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1827, 3653, 0], coalesce(var.log_retention_es_application_logs, 2))
    )

    error_message = "Valid log retention values: 1,3,5,7,14,30,60,90,120,150,180,365,400,545,731,1827,3653,0."
  }
}

variable "log_retention_audit_logs" {
  description = <<-EOT
  Specifies the number of days you want to retain AUDIT_LOGS log events.
  Possible values are: 1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1827, 3653, and 0.
  If you select 0, the events in the log group are always retained and never expire.
  EOT
  type        = number
  default     = null

  validation {
    condition = (
      var.log_retention_audit_logs == null ||
      contains([1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1827, 3653, 0], coalesce(var.log_retention_audit_logs, 2))
    )

    error_message = "Valid log retention values: 1,3,5,7,14,30,60,90,120,150,180,365,400,545,731,1827,3653,0."
  }
}

variable "master_user_name" {
  type = string
}

variable "master_user_password" {
  type = string
}

variable "read_only_roles" {
  type    = list(string)
  default = []
}

variable "read_write_roles" {
  type    = list(string)
  default = []
}

variable "security_group_ids" {
  type = list(string)
  ## sic: these are provided by the env_definitions file
  default = []
}

variable "subnet_ids" {
  type = list(string)
  ## sic: these are provided by the env_definitions file
  default = []
}

variable "tags" {
  description = "Tags for Opensearch"
  type        = map(string)
}

variable "vpc_id" {
  type = string
}

variable "warm_enabled" {
  type = string
}

variable "warm_count" {
  type    = number
  default = null
}

variable "warm_type" {
  type    = string
  default = null
}

## Advanced Options ##
## -------------------

variable "indices_query_bool_max_clause_count" {
  description = "Max number of bool clause"
  type        = number
  default     = 1024
}
